#
# spec file for package povray
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define maj_version 3.7
%define min_version 0.10
Name:           povray
Version:        %{maj_version}.%{min_version}
Release:        1.13
Summary:        Persistence of Vision Raytracer
License:        AGPL-3.0-or-later AND CC-BY-SA-3.0
Group:          Productivity/Graphics/Visualization/Raytracers
URL:            https://www.povray.org/
Source:         https://github.com/POV-Ray/povray/archive/v%{version}.tar.gz
Patch1:         povray-3.6.9.7-ini.patch
Patch2:         povray-3.6.9.7-fix.patch
# PATCH-FIX-UPSTREAM bmwiedemann
Patch5:         reproducible.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(zlib)
Recommends:     povray-doc

%description
The Persistence of Vision Ray tracer creates three-dimensional,
photo-realistic images using a rendering technique called ray tracing.
It reads in a text file containing information describing the objects
and lighting in a scene and generates an image of that scene from the
view point of a camera also described in the text file. Ray tracing is
not a fast process by any means, (the generation of a complex image can
take several hours) but it produces very high quality images with
realistic reflections, shading, perspective, and other effects.

%package doc
Summary:        Documentation for POV-Ray
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package contains the Povray documentation.

%prep
%setup -q
%patch1
%patch2
%patch5 -p1

# remove inline copies of shared libraries
rm -rf libraries

# add missing standard files
sed -i 's,automake --warnings=all,automake --warnings=all --add-missing,' \
    unix/prebuild.sh

# fix wrong newline encoding
dos2unix -k unix/scripts/*.sh

%build
( cd unix && ./prebuild.sh )
%configure \
    COMPILED_BY=%{vendor} \
    --disable-strip \
    --disable-optimiz \
    --with-boost-libdir=%{_libdir}

# fix up paths
sed -i -e 's,^DEFAULT_DIR=.*,DEFAULT_DIR=/usr,' scripts/*
sed -i -e 's,^SYSCONFDIR=.*,SYSCONFDIR=/etc,' scripts/*

%make_build

%install
%make_install povdocdir=%{_defaultdocdir}/povray

# fix wrong permissions
chmod 755 %{buildroot}%{_datadir}/povray-%{maj_version}/scenes/camera/mesh_camera/bake.sh

%fdupes %{buildroot}/%{_datadir}

%files
%doc AUTHORS README.md changes.txt revision.txt
%doc %{_defaultdocdir}/povray/{ChangeLog,NEWS}
%license LICENSE
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/%{maj_version}
%config(noreplace) %{_sysconfdir}/%{name}/%{maj_version}/%{name}.*
%{_bindir}/povray
%{_datadir}/povray-%{maj_version}
%{_mandir}/man1/povray.1%{?ext_man}
%exclude %{_defaultdocdir}/povray/html

%files doc
%{_defaultdocdir}/povray/html

%changelog
* Mon Jul 25 2022 Dirk Müller <dmueller@suse.com>
- update to 3.7.0.10:
  * This is POV-Ray v3.7.0.10, a maintenance update of POV-Ray v3.7.0, intended to
    further improve source code compatibility with modern build environments
* Fri May 20 2022 Jan Engelhardt <jengelh@inai.de>
- Build docs as noarch
- Use more pkgconfig() to refer to BuildRequires
* Thu Feb 13 2020 Stanislav Brabec <sbrabec@suse.com>
- Fix typo in RPM group.
* Mon Feb  3 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to maintenance release 3.7.0.8
  * Changes between 3.7.0.7 and 3.7.0.8
    + Modify thread creation code to more easily address thread stack size issues
    in Mac OS builds (requires Boost 1.50 or later to be effective).
  * Changes between 3.7.0.6 and 3.7.0.7
    + Fix configure script failing to properly handle `.` directory in
    `C_INCLUDE_PATH` or `CPLUS_INCLUDE_PATH` (fixes GitHub issue #342,
    "AX_FIX_INCORRECT_PATH is broken").
  * Changes between 3.7.0.5 and 3.7.0.6
    + Fix configure script failing to use -lboost_system with Boost 1.66
    (fixes GitHub issue #341, "macOS build failure for 3.7.0.5").
  * Changes between 3.7.0.4 and 3.7.0.5
    + Fixed compatibility with systems defining `NULL` as `0` when using
    `shared_ptr` from C++11 rather than boost/tr1 (GitHub issue #339).
    + Fixed compatibility with systems not exposing `atof` in the global
    namespace (reported in discussion about GitHub issue #317).
    + Eliminated use of `register` keyword to silence warnings with C++11 (where
    the keyword is deprecated) and improve compatibility with C++17 (where the
    keyword is disallowed).
  * Changes between 3.7.0.3 and 3.7.0.4
    + Fixed minor error in Unix man page.
    + Partially fixed incompatibility with Boost 1.65.0.
  * Changes between 3.7.0.2 and 3.7.0.3
    + Updated OpenEXR file handling code to be compatible with GNU C++ compiler
    g++ 6.x (missed that code portion in 3.7.0.2).
    + Fixed a bug discovered in bicubic patch code that could theoretically lead
    to unpredictable behaviour. (To our knowledge, the official 3.7.0 Windows
    binaries should be safe.)
  * Changes between 3.7.0.1 and 3.7.0.2
    + Updated the bundled boost library to version 1.62, as the version bundled
    with the 3.7.0.1 source code (boost 1.59) turned out to have a bug that
    would have caused POV-Ray for Windows to wake the computer from sleep mode
    even when not currently rendering.
    + Updated code to be compatible with GNU C++ compiler g++ 6.x (tested with
    6.3.1).
  * Changes between 3.7.0 and 3.7.0.1
    + Updated the Unix build process to be compatible with modern versions of
    Automake.
    + Updated the Unix build process to automatically link the `boost_system`
    library if required, to be compatible with modern versions of the boost
    libraries.
    + Updated the source code to eliminate conflicts with C++11.
    + Updated the Unix-specific source code and build process to be compatible
    with Mac OS X.
- Drop obsolete povray-3.6.9.7-boost-link.patch
- Correct License, with Povray 3.7.0 the license changed to
  AGPL-3.0-or-later, see http://www.povray.org/download/
- Package documentation
* Mon May 22 2017 bwiedemann@suse.com
- Add reproducible.patch to sort input files to make build reproducible
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sat Jul 16 2016 antoine.belvire@laposte.net
- Fix build with GCC 6 (boo#985057):
  * Add '-std=c++03' to CXXFLAGS
* Wed Apr 22 2015 gber@opensuse.org
- update to version 3.7.0.0
  - see http://www.povray.org/download/changes.txt for a list of
    changes
- relicensed as AGPL-3.0 (software) and CC-BY-SA-3.0 (includes,
  examples)
- removed unused povray-3.6.9.7-TIME_UTC_.patch
- clean up spec file
* Sat Jul 13 2013 alinm.elena@gmail.com
- update to 3.7.RC7
  * added patch  povray-3.6.9.7-boost-link.patch
  * allows boost to be linked
  * renamed all the patches to correspond to the version bump
  * updated patch TIME_UTC_.patch to reflect changes to source
  * BuildRequires: libSDL-devel openexr-devel
* Mon Nov 26 2012 jengelh@inai.de
- Parallel build with %%_smp_mflags
- Remove redundant/unwanted tags/sections from specfile
* Wed Sep  5 2012 pgajdos@suse.com
- updated to 3.7.RC6 (builds against libpng15)
  * removed wronglibdetect.patch
  * removed libpng14.patch
  * added TIME_UTC_.patch
  * buildrequire boost-devel
* Mon Jun 18 2012 cfarrell@suse.com
- license update: SUSE-NonFree
  Package should be moved to NonFree. The license agreement is not suitable
  for openSUSE
* Tue Jan 10 2012 crrodriguez@opensuse.org
- Fix buildRequires and build on Factory
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Apr  6 2010 pgajdos@suse.cz
- ported to new libpng14
* Sun Jun  1 2008 crrodriguez@suse.de
- Do not ever use bundled libpng,zlib,tiff
- needs fno-strict-aliasing
* Fri Jan 25 2008 meissner@suse.de
- last fix could still overflow buffer, the compiler just
  did not warn anymore.
- still uses builtin copy of libpng.
* Thu Jan 24 2008 coolo@suse.de
- fix build
* Mon Sep 18 2006 dmueller@suse.de
- build parallel
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 15 2005 uli@suse.de
- build with -O1 on ARM to work around ICE
* Fri Jul 29 2005 nadvornik@suse.cz
- updated to 3.6.1
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Wed Jul 30 2003 nadvornik@suse.cz
- really use RPM_OPT_FLAGS
* Tue Jul 29 2003 nadvornik@suse.cz
- updated to 3.50c
* Mon Dec  2 2002 ro@suse.de
- link with libpthread
* Thu Aug 29 2002 nadvornik@suse.cz
- enable access to whole filesystem by default
- set display off by default to be compatible with previous version
* Mon Aug 26 2002 nadvornik@suse.cz
- marked files in /etc as config
* Wed Aug  7 2002 nadvornik@suse.cz
- updated to 3.50a
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Wed Apr 24 2002 nadvornik@suse.cz
- used macro %%{_lib}
* Tue Feb 26 2002 nadvornik@suse.cz
- fixed file permissions in /usr/lib/povray31
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Mon Nov 12 2001 ro@suse.de
- no svgalib
* Wed Mar  7 2001 uli@suse.de
- added xf86 to neededforbuild
* Wed Jan  3 2001 nadvornik@suse.cz
- fixed povray.ini [#5012]
* Thu Sep 21 2000 nadvornik@suse.cz
- added BuildRoot
- added URL
- installed sample scenes
* Mon Jun 19 2000 kasal@suse.cz
- Added Group: tag
* Thu Feb 24 2000 kasal@suse.de
- added a trick to remove dependencies on xf86 and svgalib
* Mon Jan 17 2000 nashif@suse.de
- update to 3.1g
- moved man pages to /usr/share
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Feb 17 1999 ro@suse.de
- compile with mieee on alpha
* Thu Jan 14 1999 ro@suse.de
- svgalib version only built on ix86
* Tue Nov  4 1997 ro@suse.de
- version 3.02
  add demo sources and psdoc
* Thu Feb  6 1997 rj@suse.de
- version 3.0.10
  - new package replaces 2.2.1
